@@ -2,11 +2,12 @@ from copy import deepcopy
 
 
 def dict_merge(first, second):
-    '''Recursively merges dict's.
+    '''Recursively merges dicts.
 
-    Not just simple first['key'] = second['key'], if
-    both first and second have a key who's value is a dict then dict_merge is
-    called on both values and the result stored in the returned dictionary.
+    Not just simply first['key'] = second['key'].
+    If both first and second have a key who's value is a dict then dict_merge
+    is called on both values and the result is stored in the returned
+    dictionary.
     '''
 
     if not isinstance(second, dict):
